@@ -1,5 +1,8 @@
-package Params::Validate;
-$Params::Validate::VERSION = '1.12';
+package    # hide from PAUSE
+    Params::Validate;
+
+our $VERSION = '1.18';
+
 BEGIN { $ENV{PARAMS_VALIDATE_IMPLEMENTATION} = 'PP' }
 use Params::Validate;
 
